@@ -20,7 +20,7 @@ from keystoneclient.contrib.ec2 import utils as ec2_utils
 from lxml import etree
 from oslo_config import cfg
 from oslo_log import log
-import six.moves.urllib.parse as urlparse
+import urllib.parse as urlparse
 
 from os_collect_config import common
 from os_collect_config import exc
